import React, { ReactNode, InputHTMLAttributes, TextareaHTMLAttributes } from "react";
import SimpleBar from "simplebar-react";
interface AccordionItemProps {
    setExpanded: React.Dispatch<React.SetStateAction<number>>;
    index: number;
    title: ReactNode;
    body: ReactNode;
    expanded?: boolean;
}
declare const AccordionItem: React.FC<AccordionItemProps>;
interface AccordionItem {
    title: string;
    body: ReactNode;
    Icon?: React.FC<React.SVGAttributes<SVGElement>>;
}
interface AccordionProps {
    items: AccordionItem[];
}
export const Accordion: React.FC<AccordionProps>;
interface BaseButtonProps {
    variant?: "primary" | "secondary" | "tertiary";
    small?: boolean;
    isLoading?: boolean;
}
interface ButtonProps extends Omit<BaseButtonProps, "$loading"> {
    disabled?: boolean;
    text: string;
    Icon?: React.FC<React.SVGAttributes<SVGElement>>;
    onClick?: React.MouseEventHandler<HTMLButtonElement>;
}
export const Button: React.FC<ButtonProps>;
interface CardProps {
    round?: boolean;
    hover?: boolean;
}
export const Card: import("styled-components").StyledComponent<"div", any, CardProps, never>;
export const Box: import("styled-components").StyledComponent<"div", any, {}, never>;
interface DisplayIconProps {
    text: string;
    Icon: React.FC<React.SVGAttributes<SVGElement>>;
    label?: string;
}
export const DisplayIcon: React.FC<DisplayIconProps>;
export const DisplayLarge: React.FC<DisplayIconProps>;
export const DisplaySmall: React.FC<DisplayIconProps>;
export const ScrollbarContainer: import("styled-components").StyledComponent<typeof SimpleBar, any, {}, never>;
interface IItem {
    selected?: boolean;
    current?: boolean;
}
interface IBaseItem extends IItem, Omit<React.HTMLAttributes<HTMLDivElement>, "onClick"> {
    text: string;
    Icon?: React.FC<React.SVGAttributes<SVGElement>>;
    dot?: string;
    onClick?: () => void;
}
interface _IItem1 extends IBaseItem {
    value: number | string;
}
interface ISelect {
    items: _IItem1[];
    callback: (value: _IItem1["value"]) => void;
    defaultValue?: _IItem1["value"];
    placeholder?: Omit<_IItem1, "value">;
    simpleButton?: boolean;
    smallButton?: boolean;
    alignRight?: boolean;
}
export const DropdownSelect: React.FC<ISelect>;
interface _IItem2 {
    label: string;
    value: number | string;
    children?: _IItem2[];
}
interface ICascader {
    items: _IItem2[];
    onSelect: (value: _IItem2["value"]) => void;
    placeholder: string;
}
export const DropdownCascader: React.FC<ICascader>;
type VariantProp = {
    variant?: "success" | "warning" | "error" | string;
};
type FieldProps = VariantProp & InputHTMLAttributes<HTMLInputElement> & {
    message?: string;
};
export const Field: React.FC<FieldProps>;
export const Searchbar: React.FC<React.InputHTMLAttributes<HTMLInputElement>>;
type TextareaProps = VariantProp & TextareaHTMLAttributes<HTMLTextAreaElement> & {
    message?: string;
};
export const Textarea: React.FC<TextareaProps>;
export const Slider: React.ForwardRefExoticComponent<{
    label?: string | undefined;
    style?: React.CSSProperties | undefined;
    defaultValue?: number | undefined;
    className?: string | undefined;
    tabIndex?: number | undefined;
    onFocus?: ((e: React.FocusEvent<HTMLDivElement, Element>) => void) | undefined;
    onBlur?: ((e: React.FocusEvent<HTMLDivElement, Element>) => void) | undefined;
    onChange?: ((value: number) => void) | undefined;
    max?: number | undefined;
    min?: number | undefined;
    autoFocus?: boolean | undefined;
    disabled?: boolean | undefined;
    value?: number | undefined;
    step?: number | null | undefined;
    reverse?: boolean | undefined;
    vertical?: boolean | undefined;
    callback: (value: number) => void;
    prefixCls?: string | undefined;
    onBeforeChange?: ((value: number) => void) | undefined;
    onAfterChange?: ((value: number) => void) | undefined;
    included?: boolean | undefined;
    minimumTrackStyle?: React.CSSProperties | undefined;
    trackStyle?: React.CSSProperties | undefined;
    handleStyle?: React.CSSProperties | undefined;
    ariaLabelForHandle?: string | undefined;
    ariaLabelledByForHandle?: string | undefined;
    ariaValueTextFormatterForHandle?: ((value: number) => string) | undefined;
    startPoint?: number | undefined;
    handle?: ((props: {
        className: string;
        prefixCls?: string | undefined;
        vertical?: boolean | undefined;
        offset: number;
        value: number;
        dragging?: boolean | undefined;
        disabled?: boolean | undefined;
        min?: number | undefined;
        max?: number | undefined;
        reverse?: boolean | undefined;
        index: number;
        tabIndex?: number | undefined;
        ariaLabel: string;
        ariaLabelledBy: string;
        ariaValueTextFormatter?: ((value: number) => string) | undefined;
        style?: React.CSSProperties | undefined;
        ref?: React.Ref<any> | undefined;
    }) => React.ReactElement<any, string | React.JSXElementConstructor<any>>) | undefined;
    marks?: Record<number, React.ReactNode | {
        style?: React.CSSProperties | undefined;
        label?: string | undefined;
    }> | undefined;
    dots?: boolean | undefined;
    maximumTrackStyle?: React.CSSProperties | undefined;
    railStyle?: React.CSSProperties | undefined;
    dotStyle?: React.CSSProperties | undefined;
    activeDotStyle?: React.CSSProperties | undefined;
    draggableTrack?: boolean | undefined;
    leftLabel: string;
    rightLabel: string;
} & {
    theme?: any;
}>;
type _VariantProp1 = {
    variant?: "success" | "warning" | "error" | "info";
};
interface FileUploaderProps extends _VariantProp1 {
    callback: Function;
    msg?: string;
    info?: boolean;
}
export const FileUploader: React.FC<FileUploaderProps>;
interface IDatePicker {
    onSelect: (date: Date) => void;
    time?: boolean;
}
export const Datepicker: React.FC<IDatePicker>;
interface RadioBaseProps {
    small?: boolean;
    checked?: boolean;
}
interface RadioProps extends RadioBaseProps, Omit<InputHTMLAttributes<HTMLInputElement>, "type"> {
    label: string;
}
export const Radio: React.FC<RadioProps>;
interface CheckboxBaseProps {
    checked?: boolean;
    small?: boolean;
}
interface CheckboxProps extends CheckboxBaseProps, Omit<InputHTMLAttributes<HTMLInputElement>, "type"> {
    label: string;
}
export const Checkbox: React.FC<CheckboxProps>;
interface SwitchBaseProps {
    small?: boolean;
    checked?: boolean;
}
type SwitchProps = SwitchBaseProps & Omit<InputHTMLAttributes<HTMLInputElement>, "type">;
export const Switch: React.FC<SwitchProps>;
type _VariantProp2 = {
    variant: "success" | "warning" | "error" | "info";
};
interface AlertProps extends _VariantProp2 {
    title: string;
    msg: string;
}
export const AlertMessage: React.FC<AlertProps>;
type SmallProp = {
    small?: boolean;
};
type _VariantProp3 = {
    variant?: "success" | "error" | "sync";
};
interface PushProps extends SmallProp, _VariantProp3 {
    title: string;
    msg?: string;
    callback: Function;
}
export const PushMessage: React.FC<PushProps>;
interface CompactPaginationProps {
    currentPage: number;
    numPages: number;
    callback: Function;
    label?: ReactNode;
    className?: string;
}
export const CompactPagination: React.FC<CompactPaginationProps>;
interface _CompactPaginationProps1 {
    currentPage: number;
    numPages: number;
    callback: Function;
    className?: string;
}
export const StandardPagination: React.FC<_CompactPaginationProps1>;
interface TabsItem {
    text: string;
    value: any;
    Icon?: React.FC<React.SVGAttributes<SVGElement>>;
    disabled?: boolean;
}
interface TabsProps {
    currentValue: any;
    items: TabsItem[];
    callback: Function;
}
export const Tabs: React.FC<TabsProps>;
interface BreadcrumbProps {
    items: {
        text: string;
        value: any;
    }[];
    callback?: Function;
    clickable?: boolean;
    className?: string;
}
export const Breadcrumb: React.FC<BreadcrumbProps>;
interface LineBaseProps {
    animated?: boolean;
    width: number;
}
interface LinearProps extends LineBaseProps {
    text?: string;
    progress: number;
    timerText?: ReactNode;
}
export const LinearProgress: React.FC<LinearProps>;
interface ProgressBaseProps {
    progress: number;
    animated?: boolean;
}
interface CircularProps extends ProgressBaseProps {
    small?: boolean;
}
export const CircularProgress: React.FC<CircularProps>;
interface StepItem {
    title: string;
    subitems?: string[];
}
interface StepsProps {
    items: StepItem[];
    currentItemIndex: number;
    horizontal?: boolean;
}
export const Steps: React.FC<StepsProps>;
type _VariantProp4 = {
    variant?: "accepted" | "refused";
};
interface SideProp {
    rightSided?: boolean;
}
interface TimelineItem extends SideProp, VariantProp {
    title: string;
    party: string;
    subtitle: string;
}
interface TimelineProps {
    items: [TimelineItem, ...TimelineItem[]];
}
export const Timeline: React.FC<TimelineProps>;
interface BaseTagProps {
    active?: boolean;
}
interface TagProps extends BaseTagProps {
    text: string;
}
export const Tag: React.FC<TagProps>;
interface TooltipBaseProps {
    place?: "left" | "right" | "top" | "bottom";
    small?: boolean;
}
interface TooltipProps extends TooltipBaseProps {
    text: string;
    children?: React.ReactNode;
}
export const Tooltip: React.FC<TooltipProps>;
export const lightTheme: {
    klerosUIComponentsPrimaryPurple: string;
    klerosUIComponentsSecondaryPurple: string;
    klerosUIComponentsMediumPurple: string;
    klerosUIComponentsLightPurple: string;
    klerosUIComponentsPrimaryBlue: string;
    klerosUIComponentsSecondaryBlue: string;
    klerosUIComponentsMediumBlue: string;
    klerosUIComponentsLightBlue: string;
    klerosUIComponentsPrimaryText: string;
    klerosUIComponentsSecondaryText: string;
    klerosUIComponentsStroke: string;
    klerosUIComponentsLightGrey: string;
    klerosUIComponentsWhiteBackground: string;
    klerosUIComponentsLightBackground: string;
    klerosUIComponentsDefaultShadow: string;
    klerosUIComponentsHoveredShadow: string;
    klerosUIComponentsSuccess: string;
    klerosUIComponentsSuccessLight: string;
    klerosUIComponentsWarning: string;
    klerosUIComponentsWarningLight: string;
    klerosUIComponentsError: string;
    klerosUIComponentsErrorLight: string;
    klerosUIComponentsTint: string;
    klerosUIComponentsTintMedium: string;
    klerosUIComponentsTintPurple: string;
    klerosUIComponentsTransitionSpeed: string;
};
export const darkTheme: {
    klerosUIComponentsPrimaryPurple: string;
    klerosUIComponentsSecondaryPurple: string;
    klerosUIComponentsMediumPurple: string;
    klerosUIComponentsLightPurple: string;
    klerosUIComponentsPrimaryBlue: string;
    klerosUIComponentsSecondaryBlue: string;
    klerosUIComponentsMediumBlue: string;
    klerosUIComponentsLightBlue: string;
    klerosUIComponentsPrimaryText: string;
    klerosUIComponentsSecondaryText: string;
    klerosUIComponentsStroke: string;
    klerosUIComponentsLightGrey: string;
    klerosUIComponentsWhiteBackground: string;
    klerosUIComponentsLightBackground: string;
    klerosUIComponentsDefaultShadow: string;
    klerosUIComponentsHoveredShadow: string;
    klerosUIComponentsSuccess: string;
    klerosUIComponentsSuccessLight: string;
    klerosUIComponentsWarning: string;
    klerosUIComponentsWarningLight: string;
    klerosUIComponentsError: string;
    klerosUIComponentsErrorLight: string;
    klerosUIComponentsTint: string;
    klerosUIComponentsTintMedium: string;
    klerosUIComponentsTintPurple: string;
    klerosUIComponentsTransitionSpeed: string;
};
export const veaTheme: {
    klerosUIComponentsPrimaryPurple: string;
    klerosUIComponentsSecondaryPurple: string;
    klerosUIComponentsMediumPurple: string;
    klerosUIComponentsLightPurple: string;
    klerosUIComponentsPrimaryBlue: string;
    klerosUIComponentsSecondaryBlue: string;
    klerosUIComponentsMediumBlue: string;
    klerosUIComponentsLightBlue: string;
    klerosUIComponentsPrimaryText: string;
    klerosUIComponentsSecondaryText: string;
    klerosUIComponentsStroke: string;
    klerosUIComponentsLightGrey: string;
    klerosUIComponentsWhiteBackground: string;
    klerosUIComponentsLightBackground: string;
    klerosUIComponentsDefaultShadow: string;
    klerosUIComponentsHoveredShadow: string;
    klerosUIComponentsSuccess: string;
    klerosUIComponentsSuccessLight: string;
    klerosUIComponentsWarning: string;
    klerosUIComponentsWarningLight: string;
    klerosUIComponentsError: string;
    klerosUIComponentsErrorLight: string;
    klerosUIComponentsTint: string;
    klerosUIComponentsTintMedium: string;
    klerosUIComponentsTintPurple: string;
    klerosUIComponentsTransitionSpeed: string;
};

//# sourceMappingURL=types.d.ts.map
